Django Remove WWW — django-removewww 0.1 documentation

# Django Remove WWW

Django Remove WWW is a Django middleware application that removes the WWW subdomain.

The middleware inspects the request’s host for the `www` subdomain, and redirects if `REMOVE_WWW` is `True`. It silently passes if `PREPEND_WWW` is also `True`. For some reason, Django won’t include a `REMOVE_WWW` setting. Thanks to Daniel Ryan’s GitHub Gist for some inspiration.

- Package distribution
- Code repository
- Documentation
- Tests

## Install

    $ pip install django-removewww

Add to `settings.py`.

    MIDDLEWARE = [
        # ...
        'removewww.middleware.RemoveWwwMiddleware',
    ]

    REMOVE_WWW = True

Adding to `INSTALLED_APPS` is unnecessary unless you want to run the tests.

## Contents

- Install
- Documentation
- Tests

## Indices and tables

- Index
- Module Index
- Search Page